@@ -1,6 +1,6 @@
+use fvm_ipld_encoding::tuple::{Deserialize_tuple, Serialize_tuple};
 use fvm_shared::bigint::bigint_ser;
 use fvm_shared::econ::TokenAmount;
-use fvm_shared::encoding::tuple::*;
 
 pub mod miner {
     use super::*;
